@@ -423,4 +423,7 @@ class DeviceState:
         elif value == FanMode.Quite:
             self.quite = True
         else:
-            self.fanSpeed = FanSpeed(int(value))
\ No newline at end of file
+            self.fanSpeed = FanSpeed(int(value))
+
+    def __eq__(self, o: object) -> bool:
+        return str(self) == str(o)
